/// <reference types="node" />
import { IncomingHttpHeaders, OutgoingHttpHeaders } from "http";
/**
 * Data type of input to request transformation function.
 */
export declare type ReqTransformIn = {
    /**
     * Enables the transformation function to have differentiated logic depending on the
     * endpoint's path.
     */
    path: string;
    /**
     * The object payload of the original request.
     */
    data: unknown;
    /**
     * The headers of the original request.
     */
    headers: IncomingHttpHeaders;
};
/**
 * Data type of output of request transformation function.
 */
export declare type ReqTransformOut = {
    /**
     * The transformed object payload.
     */
    data?: unknown;
    /**
     * The transformed headers.
     */
    headers?: IncomingHttpHeaders;
};
/**
 * Data type of input to response transformation function.
 */
export declare type ResTransformIn = {
    /**
     * Enables the transformation function to have differentiated logic depending on the
     * endpoint's path.
     */
    path: string;
    /**
     * The object content of the target service's response.
     */
    data: unknown;
    /**
     * The headers of the target service's response.
     */
    headers: OutgoingHttpHeaders;
};
/**
 * Data type of output of response transformation function.
 */
export declare type ResTransformOut = {
    /**
     * The transformed response object.
     */
    data?: unknown;
    /**
     * The transformed headers.
     */
    headers?: OutgoingHttpHeaders;
};
/**
 * Implements the proxy server.
 *
 * @param prxPort The port on which the proxy listens.
 * @param baseSvcUrl The URL of the target service that is being proxied.
 * @param options Optional functions to transform the request body and/or response data.
 *  The transform functions do not need to set the headers for content-type, host, and
 *  content-length as they are set automatically. If the `headers` field of a transform
 *  function response is undefined then the original untransformed headers are used, with
 *  the appropriate automatic setting of the host and content-length headers.
 */
export declare function proxy(prxPort: number, baseSvcUrl: string, options?: {
    reqTransform?: (input: ReqTransformIn) => ReqTransformOut;
    resTransform?: (input: ResTransformIn) => ResTransformOut;
}): void;
